You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by ch...@apache.org on 2018/08/09 18:13:44 UTC

[mesos] branch master updated: Built gRPC support in mesos-tidy.

This is an automated email from the ASF dual-hosted git repository.

chhsiao pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mesos.git


The following commit(s) were added to refs/heads/master by this push:
     new 874c752  Built gRPC support in mesos-tidy.
874c752 is described below

commit 874c752316b14055c0a5a7b67f97ccf912abcc3c
Author: Chun-Hung Hsiao <ch...@mesosphere.io>
AuthorDate: Tue Aug 7 16:54:17 2018 -0700

    Built gRPC support in mesos-tidy.
    
    Review: https://reviews.apache.org/r/68265
---
 support/mesos-tidy/Dockerfile    | 10 ++++++----
 support/mesos-tidy/entrypoint.sh |  9 ++++++---
 2 files changed, 12 insertions(+), 7 deletions(-)

diff --git a/support/mesos-tidy/Dockerfile b/support/mesos-tidy/Dockerfile
index 66adbd0..ea28e40 100644
--- a/support/mesos-tidy/Dockerfile
+++ b/support/mesos-tidy/Dockerfile
@@ -20,8 +20,8 @@ MAINTAINER The Apache Mesos Developers <de...@mesos.apache.org>
 WORKDIR /tmp/build
 
 # Build Mesos-flavored `clang-tidy`.
-RUN apt-get update
-RUN apt-get install -qy --no-install-recommends \
+RUN apt-get update && \
+  apt-get install -qy --no-install-recommends \
   build-essential \
   ca-certificates \
   curl \
@@ -54,7 +54,8 @@ ENV PATH /opt/bin:$PATH
 
 # Install Mesos dependencies
 # TODO(mpark): Remove `libssl-dev` from this list once `MESOS-6942` is resolved.
-RUN apt-get install -qy \
+RUN apt-get update && \
+  apt-get install -qy \
   autoconf \
   libacl1-dev \
   libapr1-dev \
@@ -68,7 +69,8 @@ RUN apt-get install -qy \
   apt-get clean
 
 # Install `jq` and `parallel` for `clang-tidy` invocation.
-RUN apt-get install -qy \
+RUN apt-get update && \
+  apt-get install -qy \
   jq \
   parallel && \
   apt-get clean
diff --git a/support/mesos-tidy/entrypoint.sh b/support/mesos-tidy/entrypoint.sh
index bb6344c..0d584b8 100755
--- a/support/mesos-tidy/entrypoint.sh
+++ b/support/mesos-tidy/entrypoint.sh
@@ -39,6 +39,7 @@ cmake --build 3rdparty --target boost-1.65.0 -- -j $(nproc)
 cmake --build 3rdparty --target elfio-3.2 -- -j $(nproc)
 cmake --build 3rdparty --target glog-0.3.3 -- -j $(nproc)
 cmake --build 3rdparty --target googletest-1.8.0 -- -j $(nproc)
+cmake --build 3rdparty --target grpc-1.10.0 -- -j $(nproc)
 cmake --build 3rdparty --target http_parser-2.6.2 -- -j $(nproc)
 
 # TODO(mpark): The `|| true` is a hack to try both `libev` and `libevent` and
@@ -58,10 +59,12 @@ cmake --build 3rdparty --target zookeeper-3.4.8 -- -j $(nproc)
 cmake --build . --target mesos-protobufs -- -j $(nproc)
 
 # For protobuf definitions in stout (`protobuf-test.pb.h`) or
 # libprocess (`benchmarks.pb.h`) no explict targets exists; we instead
 # build the executable targets to produce them as a side-effect.  This
 # is pretty hacky for what we want to do, but it's okay for now.
 cmake --build 3rdparty/stout/tests --target stout-tests -- -j $(nproc)
+cmake --build 3rdparty/libprocess/src/tests --target libprocess-tests -- -j $(nproc)
 cmake --build 3rdparty/libprocess/src/tests --target benchmarks -- -j $(nproc)
 
 # TODO(bbannier): Use a less restrictive `grep` pattern and `header-filter`
@@ -58,10 +59,12 @@ cmake --build 3rdparty --target zookeeper-3.4.8 -- -j $(nproc)
 
 # For protobuf definitions in stout (`protobuf-test.pb.h`) or
-# libprocess (`benchmarks.pb.h`) no explict targets exists; we instead
-# build the executable targets to produce them as a side-effect.  This
-# is pretty hacky for what we want to do, but it's okay for now.
+# libprocess (`grpc_tests.pb.h`, `grpc_tests.grpc.pb.h` and `benchmarks.pb.h`)
+# no explict targets exists; we instead build the executable targets to produce
+# them as a side-effect. This is pretty hacky for what we want to do, but it's
+# okay for now.
 cmake --build 3rdparty/stout/tests --target stout-tests -- -j $(nproc)